import {
  Alert,
  Button,
  Card,
  Space,
  Flex,
  Row,
  Col,
  Typography,
  Grid,
  Skeleton,
  notification,
} from "antd";
import { useAppContext } from "../../Contexts/AppContext";
import {
  AppStyle,
  FormatDatetime,
  myFetch,
  showUnkownErrorNotification,
} from "../../utils";
import { useTranslation } from "react-i18next";
import { CheckOutlined, CloseOutlined } from "@ant-design/icons";
import { useEffect, useState } from "react";
import { ReactComponent as RocketLaunch } from "./rocket_launch_FILL1_wght400_GRAD0_opsz24.svg";
import { ReactComponent as Check } from "./task_alt_FILL0_wght400_GRAD0_opsz24.svg";

const { useBreakpoint } = Grid;

export default function PaymentPlan() {
  const { t } = useTranslation();
  const appContext = useAppContext();

  const [notificationApi, notificationContextHolder] =
    notification.useNotification();

  const screenBreakpoint = useBreakpoint();

  const [isRequesting, setIsRequesting] = useState(true);
  const [requestData, setRequestData] = useState({
    payment_plan: 0,
    payment_plan_interval: 0,
    prices: [],
    payment_plan_trial_end: undefined,
    payment_plan_canceled_at: undefined,
  });
  const [requestingCheckout, setRequestingCheckout] = useState(false);

  const [selectedBillingPeriod, setSelectedBillingPeriod] = useState(0);

  const fetchPaymentPlan = () => {
    myFetch({
      url: "/payment",
      method: "GET",
      notificationApi,
      t,
    })
      .then((data) => {
        setRequestData(data);
        setIsRequesting(false);

        if (data.payment_plan_interval !== null) {
          setSelectedBillingPeriod(data.payment_plan_interval);
        }
      })
      .catch((error) => {
        console.log(error);
        setIsRequesting(false);
        showUnkownErrorNotification(notificationApi, t);
      });
  };

  useEffect(() => fetchPaymentPlan(), []);

  const showAlert = () => {
    if (
      !isRequesting &&
      requestData.payment_plan === 0 &&
      requestData.payment_plan_trial_end &&
      !requestData.payment_plan_canceled_at
    ) {
      return (
        <Alert
          message={
            <Typography.Text>
              Ihre Demo endet in <b>7 Tagen</b>. Jetzt einen Plan auswählen, um
              den vollen Funktionsumfang zu nutzen.
            </Typography.Text>
          }
          type="warning"
          closable
          showIcon
          style={{ marginBottom: 12 }}
        />
      );
    }
  };

  return (
    <>
      {notificationContextHolder}

      {showAlert()}

      <Card title="Features & Preisübersicht">
        <Row gutter={[16, 16]}>
          <Col xs={24} xl={12}>
            <Flex vertical>
              <Space>
                <Check />
                <Typography.Text style={{ fontSize: 20 }}>
                  Unbegrenzte <b>Terminanzahl</b>
                </Typography.Text>
              </Space>
              <Space>
                <Check />
                <Typography.Text style={{ fontSize: 20 }}>
                  Bis zu <b>20 Mitarbeiter</b>
                </Typography.Text>
              </Space>
              <Space>
                <Check />
                <Typography.Text style={{ fontSize: 20 }}>
                  Buchungen bis zu <b>6 Wochen</b> im Voraus
                </Typography.Text>
              </Space>
            </Flex>
          </Col>

          <Col xs={24} xl={12}>
            <Flex justify="center" style={{ marginBottom: 12 }}>
              <Space>
                {isRequesting ? (
                  <Skeleton.Button shape="round" size="default" active />
                ) : (
                  <Button
                    type={selectedBillingPeriod === 0 ? "primary" : "default"}
                    shape="round"
                    icon={
                      requestData.payment_plan_interval === 0 &&
                      (requestData.payment_plan_canceled_at === undefined ? (
                        <CheckOutlined />
                      ) : (
                        <CloseOutlined />
                      ))
                    }
                    onClick={() => setSelectedBillingPeriod(0)}
                  >
                    Monatlich
                  </Button>
                )}

                {isRequesting ? (
                  <Skeleton.Button shape="round" size="default" active />
                ) : (
                  <Button
                    type={selectedBillingPeriod === 1 ? "primary" : "default"}
                    shape="round"
                    icon={
                      requestData.payment_plan_interval === 1 &&
                      (requestData.payment_plan_canceled_at === undefined ? (
                        <CheckOutlined />
                      ) : (
                        <CloseOutlined />
                      ))
                    }
                    onClick={() => setSelectedBillingPeriod(1)}
                  >
                    Jährlich
                  </Button>
                )}
              </Space>
            </Flex>

            <Card style={{ backgroundColor: AppStyle.colors.primary }}>
              <Flex
                justify="space-between"
                vertical={screenBreakpoint.xs}
                align="center"
              >
                <div>
                  <RocketLaunch
                    style={{
                      width: 62,
                      height: 62,
                      backgroundColor: "#fff",
                      padding: 12,
                      borderRadius: 12,
                    }}
                  />
                </div>

                <Flex
                  vertical
                  style={{ marginBottom: screenBreakpoint.xs && 12 }}
                >
                  <Typography.Title
                    level={screenBreakpoint.xs ? 3 : 2}
                    style={{ color: "#fff" }}
                  >
                    Unternehmensplan
                  </Typography.Title>

                  {isRequesting ? (
                    <Skeleton.Button shape="round" block active />
                  ) : (
                    <Button
                      loading={requestingCheckout}
                      shape="round"
                      style={{ fontWeight: "bold" }}
                      onClick={() => {
                        setRequestingCheckout(true);

                        if (
                          selectedBillingPeriod ===
                          requestData.payment_plan_interval
                        ) {
                          myFetch({
                            method: "GET",
                            url: "/payment/portal",
                          })
                            .then((data) => {
                              if (data.url) {
                                window.location.href = data.url;
                              }
                            })
                            .catch((error) => {
                              console.log(error);
                              setRequestingCheckout(false);
                            });
                          return;
                        }

                        myFetch({
                          method: "POST",
                          url: "/payment/checkout",
                          body: {
                            lookupKey: `za-basic-${
                              selectedBillingPeriod === 0 ? "monthly" : "yearly"
                            }`,
                          },
                          notificationApi,
                          t,
                        })
                          .then((data) => {
                            console.log(data);

                            if (data.url) {
                              window.location.href = data.url;
                              return;
                            }

                            if (data.status === "ok") {
                              fetchPaymentPlan();
                              setRequestingCheckout(false);
                            }
                          })
                          .catch((error) => {
                            console.log(error);
                            setRequestingCheckout(false);
                          });
                      }}
                    >
                      {selectedBillingPeriod ===
                      requestData.payment_plan_interval
                        ? "Plan verwalten"
                        : "Jetzt buchen"}
                    </Button>
                  )}
                </Flex>

                <Flex vertical align="center">
                  {isRequesting ? (
                    <Skeleton.Button shape="round" size="large" active />
                  ) : (
                    <Typography.Title
                      level={screenBreakpoint.xs ? 3 : 2}
                      style={{
                        color: "#fff",
                        padding: 0,
                        margin: 0,
                        width: 76,
                        textAlign: "center",
                      }}
                    >
                      {`${
                        requestData.prices.find(
                          (price) =>
                            price.lookup_key ===
                            `za-basic-${
                              selectedBillingPeriod === 0 ? "monthly" : "yearly"
                            }`
                        ).unit_amount / (selectedBillingPeriod === 0 ? 1 : 12)
                      } €`}
                    </Typography.Title>
                  )}
                  <Typography.Text
                    style={{ color: "#fff", textAlign: "center" }}
                  >
                    /monatlich
                  </Typography.Text>
                </Flex>
              </Flex>
            </Card>

            {selectedBillingPeriod === requestData.payment_plan &&
              requestData.payment_plan_canceled_at !== undefined && (
                <Flex justify="center">
                  <Typography.Text type="secondary">
                    Gekündigt am{" "}
                    {FormatDatetime(requestData.payment_plan_canceled_at)} Uhr
                  </Typography.Text>
                </Flex>
              )}
          </Col>
        </Row>
      </Card>
    </>
  );
}

/*
<ChoosenProduct
        t={t}
        paymentPlan={appContext.paymentPlan}
        extra={
          <Button
            type="link"
            icon={<CreditCardOutlined />}
            loading={isRequestingBillingDetails}
            onClick={() => {
              setIsRequestingBillingDetails(true);

              myFetch({
                method: "GET",
                url: "/payment/portal",
              })
                .then((response) => (window.location.href = response.url))
                .catch(() => {
                  setIsRequestingBillingDetails(false);
                  showUnkownErrorNotification(notificationApi, t);
                });
            }}
          >
            {t("paymentPlan.buttonUpdateBillingDetails")}
          </Button>
        }
      />
    </>
*/
